@@ -1,5 +1,5 @@
 """Type definitions for Flick framework."""
 
-from .schema import Field, ConfigDict
+from .schema import ConfigDict, Field
 
 __all__ = ["Field", "ConfigDict"]
